# must check for REPL & FTP start up requirement in here
from machine import Pin
import network
import pycom
import time
import sys
import DipBoot
import DipApp

# start the run timer
DipApp.StartRunTimer()

# define rgb colours for later use
RED=0x3f0000
BLUE=0x00003f
GREEN=0x003f00
YELLOW=0x3f3f00
WHITE=0x3f3f3f
CYAN=0x003f3f
MAGENTA=0x3f003f
LEDOFF=0


# The system powers up with the default of WiFi, REPL and FTP enabled.
# If the WiFi button is held down then the system leaves REPL and Wifi debug mode operational
# If the button IS NOT held down then WiFi, REPL and FTP get disabled

wifi_switch = Pin('P16',mode=Pin.IN)
server=network.Server()
wlan=network.WLAN() #starts wifi in default AP mode
wlan.init()
wlan.mode(2)
wlan.ssid('dipstik')


# disable the flashing LED thing
pycom.heartbeat(False)


if wifi_switch() != 0:
	# BUTTON NOT PRESSED, we need to turn off WiFi, REPL and FTP for NORMAL DipStik operation
	#pycom.rgbled(GREEN)
	#time.sleep_ms(300)
	#pycom.rgbled(CYAN)
	#time.sleep_ms(300)
	#pycom.rgbled(BLUE)
	#time.sleep_ms(300)
	#pycom.rgbled(LEDOFF)
	#turn off WiFi etc for security/low power
	wlan.deinit()
	server.deinit()
	#now just fall through and start up the rest of the DipStik code.
	pass

else:
	# button pressed.
	# test button again to avoid accidental trip by TBRG
	# BUTTON MUST BE HELD DOWN FOR 2 SECONDS
	time.sleep(2)
	if wifi_switch() == 0:
		# debug/configuration mode
		#REPL is required, so set it all up
		# blue-yellow-blue flash as config mode indicator
		pycom.rgbled(BLUE)
		time.sleep_ms(300)
		pycom.rgbled(YELLOW)
		time.sleep_ms(300)
		pycom.rgbled(BLUE)
		time.sleep_ms(300)
		pycom.rgbled(LEDOFF)

		wlan.init(mode=network.WLAN.AP, ssid='dipstik')
		server.init(login=('micro','python'),timeout=600)

		###### we just want to run in DEBUG mode for now. #####
		# Turn the flashing light back on as a reminder for this mode
		#pycom.heartbeat(True)
		# now just exit
		sys.exit()
		# ****** the only way out of this is via reset/power down ******

# signal normal DipStik start up with 3 x green flashes
#time.sleep_ms(200)
#for index in range(3):
#	pycom.rgbled(GREEN) #green
#	time.sleep_ms(100)
#	pycom.rgbled(LEDOFF)
#	time.sleep_ms(400)

DipBoot.BootMain()
